//@line 36 "/builds/slave/rel-191-lnx-rpk-3/l10n-mozilla-1.9.1/hr/browser/firefox-l10n.js"

//@line 38 "/builds/slave/rel-191-lnx-rpk-3/l10n-mozilla-1.9.1/hr/browser/firefox-l10n.js"

pref("general.useragent.locale", "hr");
